@@ -18,17 +18,21 @@ from typing import Any, Dict, Mapping, Sequence, Type
 from botocore.client import BaseClient, ClientMeta
 
 from .type_defs import (
+    AttendeeCapabilitiesTypeDef,
+    AttendeeIdItemTypeDef,
     BatchCreateAttendeeResponseTypeDef,
     CreateAttendeeRequestItemTypeDef,
     CreateAttendeeResponseTypeDef,
     CreateMeetingResponseTypeDef,
     CreateMeetingWithAttendeesResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     GetAttendeeResponseTypeDef,
     GetMeetingResponseTypeDef,
     ListAttendeesResponseTypeDef,
     MeetingFeaturesConfigurationTypeDef,
     NotificationsConfigurationTypeDef,
     TranscriptionConfigurationTypeDef,
+    UpdateAttendeeCapabilitiesResponseTypeDef,
 )
 
 __all__ = ("ChimeSDKMeetingsClient",)
@@ -45,6 +49,7 @@ class BotocoreClientError(BaseException):
 class Exceptions:
     BadRequestException: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
+    ConflictException: Type[BotocoreClientError]
     ForbiddenException: Type[BotocoreClientError]
     LimitExceededException: Type[BotocoreClientError]
     NotFoundException: Type[BotocoreClientError]
@@ -73,7 +78,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
 
     def batch_create_attendee(
-        self, *, MeetingId: str, Attendees: Sequence["CreateAttendeeRequestItemTypeDef"]
+        self, *, MeetingId: str, Attendees: Sequence[CreateAttendeeRequestItemTypeDef]
     ) -> BatchCreateAttendeeResponseTypeDef:
         """
         Creates up to 100 attendees for an active Amazon Chime SDK meeting.
@@ -82,6 +87,21 @@ class ChimeSDKMeetingsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#batch_create_attendee)
         """
 
+    def batch_update_attendee_capabilities_except(
+        self,
+        *,
+        MeetingId: str,
+        ExcludedAttendeeIds: Sequence[AttendeeIdItemTypeDef],
+        Capabilities: AttendeeCapabilitiesTypeDef
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Updates `AttendeeCapabilities` except the capabilities listed in an
+        `ExcludedAttendeeIds` table.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.batch_update_attendee_capabilities_except)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#batch_update_attendee_capabilities_except)
+        """
+
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
@@ -91,7 +111,11 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
 
     def create_attendee(
-        self, *, MeetingId: str, ExternalUserId: str
+        self,
+        *,
+        MeetingId: str,
+        ExternalUserId: str,
+        Capabilities: AttendeeCapabilitiesTypeDef = ...
     ) -> CreateAttendeeResponseTypeDef:
         """
         Creates a new attendee for an active Amazon Chime SDK meeting.
@@ -107,8 +131,8 @@ class ChimeSDKMeetingsClient(BaseClient):
         MediaRegion: str,
         ExternalMeetingId: str,
         MeetingHostId: str = ...,
-        NotificationsConfiguration: "NotificationsConfigurationTypeDef" = ...,
-        MeetingFeatures: "MeetingFeaturesConfigurationTypeDef" = ...,
+        NotificationsConfiguration: NotificationsConfigurationTypeDef = ...,
+        MeetingFeatures: MeetingFeaturesConfigurationTypeDef = ...,
         PrimaryMeetingId: str = ...
     ) -> CreateMeetingResponseTypeDef:
         """
@@ -125,10 +149,10 @@ class ChimeSDKMeetingsClient(BaseClient):
         ClientRequestToken: str,
         MediaRegion: str,
         ExternalMeetingId: str,
-        Attendees: Sequence["CreateAttendeeRequestItemTypeDef"],
+        Attendees: Sequence[CreateAttendeeRequestItemTypeDef],
         MeetingHostId: str = ...,
-        MeetingFeatures: "MeetingFeaturesConfigurationTypeDef" = ...,
-        NotificationsConfiguration: "NotificationsConfigurationTypeDef" = ...,
+        MeetingFeatures: MeetingFeaturesConfigurationTypeDef = ...,
+        NotificationsConfiguration: NotificationsConfigurationTypeDef = ...,
         PrimaryMeetingId: str = ...
     ) -> CreateMeetingWithAttendeesResponseTypeDef:
         """
@@ -139,7 +163,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#create_meeting_with_attendees)
         """
 
-    def delete_attendee(self, *, MeetingId: str, AttendeeId: str) -> None:
+    def delete_attendee(self, *, MeetingId: str, AttendeeId: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes an attendee from the specified Amazon Chime SDK meeting and deletes
         their `JoinToken`.
@@ -148,7 +172,7 @@ class ChimeSDKMeetingsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#delete_attendee)
         """
 
-    def delete_meeting(self, *, MeetingId: str) -> None:
+    def delete_meeting(self, *, MeetingId: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified Amazon Chime SDK meeting.
 
@@ -198,8 +222,8 @@ class ChimeSDKMeetingsClient(BaseClient):
         """
 
     def start_meeting_transcription(
-        self, *, MeetingId: str, TranscriptionConfiguration: "TranscriptionConfigurationTypeDef"
-    ) -> None:
+        self, *, MeetingId: str, TranscriptionConfiguration: TranscriptionConfigurationTypeDef
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Starts transcription for the specified `meetingId` .
 
@@ -207,10 +231,20 @@ class ChimeSDKMeetingsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#start_meeting_transcription)
         """
 
-    def stop_meeting_transcription(self, *, MeetingId: str) -> None:
+    def stop_meeting_transcription(self, *, MeetingId: str) -> EmptyResponseMetadataTypeDef:
         """
         Stops transcription for the specified `meetingId` .
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.stop_meeting_transcription)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#stop_meeting_transcription)
         """
+
+    def update_attendee_capabilities(
+        self, *, MeetingId: str, AttendeeId: str, Capabilities: AttendeeCapabilitiesTypeDef
+    ) -> UpdateAttendeeCapabilitiesResponseTypeDef:
+        """
+        The capabilties that you want to update.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.update_attendee_capabilities)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#update_attendee_capabilities)
+        """
