@@ -6,9 +6,9 @@ Type annotations for chime-sdk-meetings service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_chime_sdk_meetings.literals import MeetingFeatureStatusType
+    from mypy_boto3_chime_sdk_meetings.literals import MediaCapabilitiesType
 
-    data: MeetingFeatureStatusType = "AVAILABLE"
+    data: MediaCapabilitiesType = "None"
     ```
 """
 import sys
@@ -20,6 +20,7 @@ else:
 
 
 __all__ = (
+    "MediaCapabilitiesType",
     "MeetingFeatureStatusType",
     "TranscribeContentIdentificationTypeType",
     "TranscribeContentRedactionTypeType",
@@ -39,6 +40,7 @@ __all__ = (
 )
 
 
+MediaCapabilitiesType = Literal["None", "Receive", "Send", "SendReceive"]
 MeetingFeatureStatusType = Literal["AVAILABLE", "UNAVAILABLE"]
 TranscribeContentIdentificationTypeType = Literal["PII"]
 TranscribeContentRedactionTypeType = Literal["PII"]
@@ -119,6 +121,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -187,6 +190,7 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
     "evidently",
@@ -234,6 +238,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
