@@ -6,15 +6,16 @@ Type annotations for chime-sdk-meetings service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_chime_sdk_meetings.type_defs import AttendeeTypeDef
+    from mypy_boto3_chime_sdk_meetings.type_defs import AttendeeCapabilitiesTypeDef
 
-    data: AttendeeTypeDef = {...}
+    data: AttendeeCapabilitiesTypeDef = {...}
     ```
 """
 import sys
 from typing import Dict, List, Sequence
 
 from .literals import (
+    MediaCapabilitiesType,
     MeetingFeatureStatusType,
     TranscribeLanguageCodeType,
     TranscribeMedicalRegionType,
@@ -36,46 +37,58 @@ else:
 
 
 __all__ = (
-    "AttendeeTypeDef",
+    "AttendeeCapabilitiesTypeDef",
+    "AttendeeIdItemTypeDef",
     "AudioFeaturesTypeDef",
-    "BatchCreateAttendeeRequestRequestTypeDef",
-    "BatchCreateAttendeeResponseTypeDef",
     "CreateAttendeeErrorTypeDef",
-    "CreateAttendeeRequestItemTypeDef",
-    "CreateAttendeeRequestRequestTypeDef",
-    "CreateAttendeeResponseTypeDef",
-    "CreateMeetingRequestRequestTypeDef",
-    "CreateMeetingResponseTypeDef",
-    "CreateMeetingWithAttendeesRequestRequestTypeDef",
-    "CreateMeetingWithAttendeesResponseTypeDef",
+    "ResponseMetadataTypeDef",
+    "NotificationsConfigurationTypeDef",
     "DeleteAttendeeRequestRequestTypeDef",
     "DeleteMeetingRequestRequestTypeDef",
     "EngineTranscribeMedicalSettingsTypeDef",
     "EngineTranscribeSettingsTypeDef",
     "GetAttendeeRequestRequestTypeDef",
-    "GetAttendeeResponseTypeDef",
     "GetMeetingRequestRequestTypeDef",
-    "GetMeetingResponseTypeDef",
     "ListAttendeesRequestRequestTypeDef",
-    "ListAttendeesResponseTypeDef",
     "MediaPlacementTypeDef",
-    "MeetingFeaturesConfigurationTypeDef",
-    "MeetingTypeDef",
-    "NotificationsConfigurationTypeDef",
-    "ResponseMetadataTypeDef",
-    "StartMeetingTranscriptionRequestRequestTypeDef",
     "StopMeetingTranscriptionRequestRequestTypeDef",
+    "AttendeeTypeDef",
+    "CreateAttendeeRequestItemTypeDef",
+    "CreateAttendeeRequestRequestTypeDef",
+    "UpdateAttendeeCapabilitiesRequestRequestTypeDef",
+    "BatchUpdateAttendeeCapabilitiesExceptRequestRequestTypeDef",
+    "MeetingFeaturesConfigurationTypeDef",
+    "EmptyResponseMetadataTypeDef",
     "TranscriptionConfigurationTypeDef",
+    "BatchCreateAttendeeResponseTypeDef",
+    "CreateAttendeeResponseTypeDef",
+    "GetAttendeeResponseTypeDef",
+    "ListAttendeesResponseTypeDef",
+    "UpdateAttendeeCapabilitiesResponseTypeDef",
+    "BatchCreateAttendeeRequestRequestTypeDef",
+    "CreateMeetingRequestRequestTypeDef",
+    "CreateMeetingWithAttendeesRequestRequestTypeDef",
+    "MeetingTypeDef",
+    "StartMeetingTranscriptionRequestRequestTypeDef",
+    "CreateMeetingResponseTypeDef",
+    "CreateMeetingWithAttendeesResponseTypeDef",
+    "GetMeetingResponseTypeDef",
 )
 
-AttendeeTypeDef = TypedDict(
-    "AttendeeTypeDef",
+AttendeeCapabilitiesTypeDef = TypedDict(
+    "AttendeeCapabilitiesTypeDef",
     {
-        "ExternalUserId": str,
+        "Audio": MediaCapabilitiesType,
+        "Video": MediaCapabilitiesType,
+        "Content": MediaCapabilitiesType,
+    },
+)
+
+AttendeeIdItemTypeDef = TypedDict(
+    "AttendeeIdItemTypeDef",
+    {
         "AttendeeId": str,
-        "JoinToken": str,
     },
-    total=False,
 )
 
 AudioFeaturesTypeDef = TypedDict(
@@ -86,23 +99,6 @@ AudioFeaturesTypeDef = TypedDict(
     total=False,
 )
 
-BatchCreateAttendeeRequestRequestTypeDef = TypedDict(
-    "BatchCreateAttendeeRequestRequestTypeDef",
-    {
-        "MeetingId": str,
-        "Attendees": Sequence["CreateAttendeeRequestItemTypeDef"],
-    },
-)
-
-BatchCreateAttendeeResponseTypeDef = TypedDict(
-    "BatchCreateAttendeeResponseTypeDef",
-    {
-        "Attendees": List["AttendeeTypeDef"],
-        "Errors": List["CreateAttendeeErrorTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 CreateAttendeeErrorTypeDef = TypedDict(
     "CreateAttendeeErrorTypeDef",
     {
@@ -113,101 +109,27 @@ CreateAttendeeErrorTypeDef = TypedDict(
     total=False,
 )
 
-CreateAttendeeRequestItemTypeDef = TypedDict(
-    "CreateAttendeeRequestItemTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "ExternalUserId": str,
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
-CreateAttendeeRequestRequestTypeDef = TypedDict(
-    "CreateAttendeeRequestRequestTypeDef",
+NotificationsConfigurationTypeDef = TypedDict(
+    "NotificationsConfigurationTypeDef",
     {
-        "MeetingId": str,
-        "ExternalUserId": str,
-    },
-)
-
-CreateAttendeeResponseTypeDef = TypedDict(
-    "CreateAttendeeResponseTypeDef",
-    {
-        "Attendee": "AttendeeTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredCreateMeetingRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateMeetingRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
-        "MediaRegion": str,
-        "ExternalMeetingId": str,
-    },
-)
-_OptionalCreateMeetingRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateMeetingRequestRequestTypeDef",
-    {
-        "MeetingHostId": str,
-        "NotificationsConfiguration": "NotificationsConfigurationTypeDef",
-        "MeetingFeatures": "MeetingFeaturesConfigurationTypeDef",
-        "PrimaryMeetingId": str,
+        "LambdaFunctionArn": str,
+        "SnsTopicArn": str,
+        "SqsQueueArn": str,
     },
     total=False,
 )
 
-
-class CreateMeetingRequestRequestTypeDef(
-    _RequiredCreateMeetingRequestRequestTypeDef, _OptionalCreateMeetingRequestRequestTypeDef
-):
-    pass
-
-
-CreateMeetingResponseTypeDef = TypedDict(
-    "CreateMeetingResponseTypeDef",
-    {
-        "Meeting": "MeetingTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredCreateMeetingWithAttendeesRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateMeetingWithAttendeesRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
-        "MediaRegion": str,
-        "ExternalMeetingId": str,
-        "Attendees": Sequence["CreateAttendeeRequestItemTypeDef"],
-    },
-)
-_OptionalCreateMeetingWithAttendeesRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateMeetingWithAttendeesRequestRequestTypeDef",
-    {
-        "MeetingHostId": str,
-        "MeetingFeatures": "MeetingFeaturesConfigurationTypeDef",
-        "NotificationsConfiguration": "NotificationsConfigurationTypeDef",
-        "PrimaryMeetingId": str,
-    },
-    total=False,
-)
-
-
-class CreateMeetingWithAttendeesRequestRequestTypeDef(
-    _RequiredCreateMeetingWithAttendeesRequestRequestTypeDef,
-    _OptionalCreateMeetingWithAttendeesRequestRequestTypeDef,
-):
-    pass
-
-
-CreateMeetingWithAttendeesResponseTypeDef = TypedDict(
-    "CreateMeetingWithAttendeesResponseTypeDef",
-    {
-        "Meeting": "MeetingTypeDef",
-        "Attendees": List["AttendeeTypeDef"],
-        "Errors": List["CreateAttendeeErrorTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DeleteAttendeeRequestRequestTypeDef = TypedDict(
     "DeleteAttendeeRequestRequestTypeDef",
     {
@@ -277,14 +199,6 @@ GetAttendeeRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetAttendeeResponseTypeDef = TypedDict(
-    "GetAttendeeResponseTypeDef",
-    {
-        "Attendee": "AttendeeTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetMeetingRequestRequestTypeDef = TypedDict(
     "GetMeetingRequestRequestTypeDef",
     {
@@ -292,14 +206,6 @@ GetMeetingRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetMeetingResponseTypeDef = TypedDict(
-    "GetMeetingResponseTypeDef",
-    {
-        "Meeting": "MeetingTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredListAttendeesRequestRequestTypeDef = TypedDict(
     "_RequiredListAttendeesRequestRequestTypeDef",
     {
@@ -322,15 +228,6 @@ class ListAttendeesRequestRequestTypeDef(
     pass
 
 
-ListAttendeesResponseTypeDef = TypedDict(
-    "ListAttendeesResponseTypeDef",
-    {
-        "Attendees": List["AttendeeTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 MediaPlacementTypeDef = TypedDict(
     "MediaPlacementTypeDef",
     {
@@ -346,14 +243,213 @@ MediaPlacementTypeDef = TypedDict(
     total=False,
 )
 
-MeetingFeaturesConfigurationTypeDef = TypedDict(
-    "MeetingFeaturesConfigurationTypeDef",
+StopMeetingTranscriptionRequestRequestTypeDef = TypedDict(
+    "StopMeetingTranscriptionRequestRequestTypeDef",
     {
-        "Audio": "AudioFeaturesTypeDef",
+        "MeetingId": str,
+    },
+)
+
+AttendeeTypeDef = TypedDict(
+    "AttendeeTypeDef",
+    {
+        "ExternalUserId": str,
+        "AttendeeId": str,
+        "JoinToken": str,
+        "Capabilities": AttendeeCapabilitiesTypeDef,
     },
     total=False,
 )
 
+_RequiredCreateAttendeeRequestItemTypeDef = TypedDict(
+    "_RequiredCreateAttendeeRequestItemTypeDef",
+    {
+        "ExternalUserId": str,
+    },
+)
+_OptionalCreateAttendeeRequestItemTypeDef = TypedDict(
+    "_OptionalCreateAttendeeRequestItemTypeDef",
+    {
+        "Capabilities": AttendeeCapabilitiesTypeDef,
+    },
+    total=False,
+)
+
+
+class CreateAttendeeRequestItemTypeDef(
+    _RequiredCreateAttendeeRequestItemTypeDef, _OptionalCreateAttendeeRequestItemTypeDef
+):
+    pass
+
+
+_RequiredCreateAttendeeRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAttendeeRequestRequestTypeDef",
+    {
+        "MeetingId": str,
+        "ExternalUserId": str,
+    },
+)
+_OptionalCreateAttendeeRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAttendeeRequestRequestTypeDef",
+    {
+        "Capabilities": AttendeeCapabilitiesTypeDef,
+    },
+    total=False,
+)
+
+
+class CreateAttendeeRequestRequestTypeDef(
+    _RequiredCreateAttendeeRequestRequestTypeDef, _OptionalCreateAttendeeRequestRequestTypeDef
+):
+    pass
+
+
+UpdateAttendeeCapabilitiesRequestRequestTypeDef = TypedDict(
+    "UpdateAttendeeCapabilitiesRequestRequestTypeDef",
+    {
+        "MeetingId": str,
+        "AttendeeId": str,
+        "Capabilities": AttendeeCapabilitiesTypeDef,
+    },
+)
+
+BatchUpdateAttendeeCapabilitiesExceptRequestRequestTypeDef = TypedDict(
+    "BatchUpdateAttendeeCapabilitiesExceptRequestRequestTypeDef",
+    {
+        "MeetingId": str,
+        "ExcludedAttendeeIds": Sequence[AttendeeIdItemTypeDef],
+        "Capabilities": AttendeeCapabilitiesTypeDef,
+    },
+)
+
+MeetingFeaturesConfigurationTypeDef = TypedDict(
+    "MeetingFeaturesConfigurationTypeDef",
+    {
+        "Audio": AudioFeaturesTypeDef,
+    },
+    total=False,
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+TranscriptionConfigurationTypeDef = TypedDict(
+    "TranscriptionConfigurationTypeDef",
+    {
+        "EngineTranscribeSettings": EngineTranscribeSettingsTypeDef,
+        "EngineTranscribeMedicalSettings": EngineTranscribeMedicalSettingsTypeDef,
+    },
+    total=False,
+)
+
+BatchCreateAttendeeResponseTypeDef = TypedDict(
+    "BatchCreateAttendeeResponseTypeDef",
+    {
+        "Attendees": List[AttendeeTypeDef],
+        "Errors": List[CreateAttendeeErrorTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateAttendeeResponseTypeDef = TypedDict(
+    "CreateAttendeeResponseTypeDef",
+    {
+        "Attendee": AttendeeTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetAttendeeResponseTypeDef = TypedDict(
+    "GetAttendeeResponseTypeDef",
+    {
+        "Attendee": AttendeeTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListAttendeesResponseTypeDef = TypedDict(
+    "ListAttendeesResponseTypeDef",
+    {
+        "Attendees": List[AttendeeTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateAttendeeCapabilitiesResponseTypeDef = TypedDict(
+    "UpdateAttendeeCapabilitiesResponseTypeDef",
+    {
+        "Attendee": AttendeeTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+BatchCreateAttendeeRequestRequestTypeDef = TypedDict(
+    "BatchCreateAttendeeRequestRequestTypeDef",
+    {
+        "MeetingId": str,
+        "Attendees": Sequence[CreateAttendeeRequestItemTypeDef],
+    },
+)
+
+_RequiredCreateMeetingRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateMeetingRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "MediaRegion": str,
+        "ExternalMeetingId": str,
+    },
+)
+_OptionalCreateMeetingRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateMeetingRequestRequestTypeDef",
+    {
+        "MeetingHostId": str,
+        "NotificationsConfiguration": NotificationsConfigurationTypeDef,
+        "MeetingFeatures": MeetingFeaturesConfigurationTypeDef,
+        "PrimaryMeetingId": str,
+    },
+    total=False,
+)
+
+
+class CreateMeetingRequestRequestTypeDef(
+    _RequiredCreateMeetingRequestRequestTypeDef, _OptionalCreateMeetingRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredCreateMeetingWithAttendeesRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateMeetingWithAttendeesRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "MediaRegion": str,
+        "ExternalMeetingId": str,
+        "Attendees": Sequence[CreateAttendeeRequestItemTypeDef],
+    },
+)
+_OptionalCreateMeetingWithAttendeesRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateMeetingWithAttendeesRequestRequestTypeDef",
+    {
+        "MeetingHostId": str,
+        "MeetingFeatures": MeetingFeaturesConfigurationTypeDef,
+        "NotificationsConfiguration": NotificationsConfigurationTypeDef,
+        "PrimaryMeetingId": str,
+    },
+    total=False,
+)
+
+
+class CreateMeetingWithAttendeesRequestRequestTypeDef(
+    _RequiredCreateMeetingWithAttendeesRequestRequestTypeDef,
+    _OptionalCreateMeetingWithAttendeesRequestRequestTypeDef,
+):
+    pass
+
+
 MeetingTypeDef = TypedDict(
     "MeetingTypeDef",
     {
@@ -361,54 +457,43 @@ MeetingTypeDef = TypedDict(
         "MeetingHostId": str,
         "ExternalMeetingId": str,
         "MediaRegion": str,
-        "MediaPlacement": "MediaPlacementTypeDef",
-        "MeetingFeatures": "MeetingFeaturesConfigurationTypeDef",
+        "MediaPlacement": MediaPlacementTypeDef,
+        "MeetingFeatures": MeetingFeaturesConfigurationTypeDef,
         "PrimaryMeetingId": str,
     },
     total=False,
 )
 
-NotificationsConfigurationTypeDef = TypedDict(
-    "NotificationsConfigurationTypeDef",
-    {
-        "LambdaFunctionArn": str,
-        "SnsTopicArn": str,
-        "SqsQueueArn": str,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
 StartMeetingTranscriptionRequestRequestTypeDef = TypedDict(
     "StartMeetingTranscriptionRequestRequestTypeDef",
     {
         "MeetingId": str,
-        "TranscriptionConfiguration": "TranscriptionConfigurationTypeDef",
+        "TranscriptionConfiguration": TranscriptionConfigurationTypeDef,
     },
 )
 
-StopMeetingTranscriptionRequestRequestTypeDef = TypedDict(
-    "StopMeetingTranscriptionRequestRequestTypeDef",
+CreateMeetingResponseTypeDef = TypedDict(
+    "CreateMeetingResponseTypeDef",
     {
-        "MeetingId": str,
+        "Meeting": MeetingTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-TranscriptionConfigurationTypeDef = TypedDict(
-    "TranscriptionConfigurationTypeDef",
+CreateMeetingWithAttendeesResponseTypeDef = TypedDict(
+    "CreateMeetingWithAttendeesResponseTypeDef",
     {
-        "EngineTranscribeSettings": "EngineTranscribeSettingsTypeDef",
-        "EngineTranscribeMedicalSettings": "EngineTranscribeMedicalSettingsTypeDef",
+        "Meeting": MeetingTypeDef,
+        "Attendees": List[AttendeeTypeDef],
+        "Errors": List[CreateAttendeeErrorTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetMeetingResponseTypeDef = TypedDict(
+    "GetMeetingResponseTypeDef",
+    {
+        "Meeting": MeetingTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
-    total=False,
 )
